%define _disable_ld_no_undefined 1

%bcond_with extracheck

%define ver	2.49.92
%define date	2018-02-18

Summary:	Common Lisp (ANSI CL) implementation
Name:		clisp
Version:	%{ver}
Release:	%mkrel 1
License:	GPLv2
Group:		Development/Other
#Source0:	https://ftp.gnu.org/gnu/clisp/latest/%{name}-%{version}.tar.bz2
Source0:	https://gitlab.com/gnu-clisp/clisp/-/archive/clisp-%{version}%{?date:-%date}/clisp-clisp-%{version}%{?date:-%date}.tar.gz
# https://sourceforge.net/p/clisp/patches/35/
Patch0:		%{name}-db.patch
# https://sourceforge.net/p/clisp/patches/32/
Patch1:		%{name}-format.patch
# The encrypt and setkey functions are no longer available from glibc
Patch2:		%{name}-setkey.patch
# Adapt to changes in pari 2.11.0
Patch3:		%{name}-pari.patch

BuildRequires:	db5.3-devel
BuildRequires:  diffutils
BuildRequires:  ffcall-devel
BuildRequires:  gdbm-devel
BuildRequires:  gettext-devel
BuildRequires:  gtk2-devel
BuildRequires:	imake
BuildRequires:  libfcgi-devel
BuildRequires:	libsigsegv-devel
BuildRequires:	locales-en
#BuildRequires:	pari-devel
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(libglade-2.0)
BuildRequires:  pkgconfig(libpcre)
BuildRequires:	pkgconfig(libxcrypt)
BuildRequires:  pkgconfig(ncursesw)
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(x11)
BuildRequires:	pkgconfig(xau)
BuildRequires:	pkgconfig(xext)
BuildRequires:	pkgconfig(xpm)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  postgresql-devel
BuildRequires:	readline-devel

Provides:       ansi-cl

# clisp contains a copy of gnulib
Provides:	bundled(gnulib)

%description
Common Lisp is a high-level, all-purpose programming language.

CLISP is a Common Lisp implementation by Bruno Haible of Karlsruhe
University and Michael Stoll of Munich University, both in Germany.

It mostly supports Common Lisp as described in the ANSI CL standard.
It runs on microcomputers (DOS, OS/2, Windows NT, Windows 95, Amiga
500-4000, Acorn RISC PC) as well as on Unix workstations (Linux,
SVR4, Sun4, DEC Alpha OSF, HP-UX, NeXTstep, SGI, AIX, Sun3 and others)
and needs only 2 MB of RAM.

It is free software and may be distributed under the terms of GNU GPL,
while it is possible to distribute commercial applications compiled
with CLISP.

The user interface comes in German, English, French and Spanish.
CLISP includes an interpreter, a compiler, a large subset of CLOS,
a foreign language interface and a socket interface.

An X11 interface is available through CLX and Garnet.


%package	devel
Summary:	Development files for CLISP
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}

%description	devel
Files necessary for linking CLISP.


%prep
%setup -qn clisp-clisp-%{version}%{?date:-%date}
%patch0 -p0
%patch1 -p0
%patch2 -p0
%patch3 -p0

# Change URLs not affected by the --hyperspec argument to configure
sed -i.orig 's|lisp.org/HyperSpec/Body/chap-7.html|lispworks.com/documentation/HyperSpec/Body/07_.htm|' \
    src/clos-package.lisp
touch -r src/clos-package.lisp.orig src/clos-package.lisp
rm -f src/clos-package.lisp.orig
for f in src/_README.*; do
  sed -i.orig 's|lisp.org/HyperSpec/FrontMatter|lispworks.com/documentation/HyperSpec/Front|' $f
  touch -r ${f}.orig $f
  rm -f ${f}.orig
done

# We only link against libraries in system directories, so we need -L dir in
# place of -Wl,-rpath -Wl,dir
cp -p src/build-aux/config.rpath config.rpath.orig
sed -i.orig -e 's/${wl}-rpath ${wl}/-L/g' src/build-aux/config.rpath

# Fix modules that need access to symbols in libgnu.a
sed -i 's/\(${GLLIB_A}\) \(${LIBS}\)/-Wl,--whole-archive \1 -Wl,--no-whole-archive \2/' src/makemake.in

%build
ulimit -s 16384
export LC_ALL=C.UTF-8

# Do not need to specify base modules: i18n, readline, regexp, syscalls.
# The dirkey module currently can only be built on Windows/Cygwin/MinGW.
# The editor module is not in good enough shape to use.
# The matlab, netica, and oracle modules require proprietary code to build.
# The queens module is intended as an example only, not for actual use.
./configure --prefix=%{_prefix} \
	    --libdir=%{_libdir} \
	    --mandir=%{_mandir} \
	    --infodir=%{_infodir} \
	    --docdir=/usr/share/doc \
	    --fsstnd=redhat \
	    --hyperspec=http://www.lispworks.com/documentation/HyperSpec/ \
	    --with-module=asdf \
	    --with-module=berkeley-db \
	    --with-module=bindings/glibc \
	    --with-module=clx/new-clx \
	    --with-module=dbus \
	    --with-module=fastcgi \
	    --with-module=gdbm \
	    --with-module=gtk2 \
%if 0
	    --with-module=libsvm \
	    --with-module=pari \
%endif
	    --with-module=pcre \
	    --with-module=postgresql \
	    --with-module=rawsock \
	    --with-module=zlib \
	    --with-libreadline-prefix=$PWD/readline \
	    --with-ffcall \
%if %{with extracheck}
	    --cbcx \
%endif
            build \
	    CFLAGS="%{optflags}" \
	    LDFLAGS="%{ldflags}"

# don't use %%make_build
make -C build

%install
%make_install  -C build
cp -a build/full %{buildroot}%{_libdir}/%{name}-%{version}
find %{buildroot}%{_libdir} -name '*.dvi' | xargs rm -f
%find_lang %{name}
%find_lang %{name}low
cat %{name}low.lang >> %{name}.lang

# Put back the original config.rpath, and fix executable bits
cp -p config.rpath.orig %{buildroot}%{_libdir}/%{name}-%{version}/build-aux/config.rpath
chmod a+x \
  %{buildroot}%{_libdir}/%{name}-%{version}/build-aux/config.guess \
  %{buildroot}%{_libdir}/%{name}-%{version}/build-aux/config.sub \
  %{buildroot}%{_libdir}/%{name}-%{version}/build-aux/depcomp \
  %{buildroot}%{_libdir}/%{name}-%{version}/build-aux/install-sh \
# Fix paths in the Makefiles
for mk in $(find %{buildroot}%{_libdir} -name Makefile); do
  sed -e "s,$PWD/modules,%{_libdir}/%{name}-%{version}," \
      -e "s,$PWD/build/clisp,%{_bindir}/clisp," \
      -e "s,$PWD/build/linkkit,%{_libdir}/%{name}-%{version}/linkkit," \
      -i $mk
done
for mk in %{buildroot}%{_libdir}/%{name}-%{version}/{base,full}/makevars; do
  sed -e "s, -I$PWD[^']*,," \
      -e "s,%{_libdir}/lib\([[:alnum:]]*\)\.so,-l\1,g" \
      -i $mk
done

# Install config.h, which is needed in some cases
for dir in %{buildroot}%{_libdir}/%{name}-%{version}/*; do
  cp -p build/$(basename $dir)/config.h $dir || :
done
cp -p build/config.h %{buildroot}%{_libdir}/%{name}-%{version}
cp -p build/clx/new-clx/config.h \
   %{buildroot}%{_libdir}/%{name}-%{version}/clx/new-clx

# Fix permissions
chmod 0755 %{buildroot}%{_bindir}/%{name}
chmod 0755 %{buildroot}%{_libdir}/%{name}-%{version}/full/lisp.run

# Fix broken symlinks in the full set
pushd %{buildroot}%{_libdir}/%{name}-%{version}/full
for obj in bogomips calls gettext readline regexi; do
  rm -f ${obj}.o
  ln -s ../base/${obj}.o ${obj}.o
done
for obj in libgnu libnoreadline lisp; do
  rm -f ${obj}.a
  ln -s ../base/${obj}.a ${obj}.a
done
for obj in fastcgi fastcgi_wrappers; do
  rm -f ${obj}.o
  ln -s ../fastcgi/${obj}.o ${obj}.o
done
rm -f bdb.o
ln -s ../berkeley-db/bdb.o bdb.o
rm -f clx.o
ln -s ../clx/new-clx/clx.o clx.o
rm -f cpcre.o
ln -s ../pcre/cpcre.o cpcre.o
rm -f dbus.o
ln -s ../dbus/dbus.o dbus.o
rm -f gdbm.o
ln -s ../gdbm/gdbm.o gdbm.o
rm -f gtk.o
ln -s ../gtk2/gtk.o gtk.o
#rm -f libsvm.o
#ln -s ../libsvm/libsvm.o libsvm.o
rm -f linux.o
ln -s ../bindings/glibc/linux.o linux.o
rm -f postgresql.o
ln -s ../postgresql/postgresql.o postgresql.o
rm -f rawsock.o
ln -s ../rawsock/rawsock.o rawsock.o
rm -f zlib.o
ln -s ../zlib/zlib.o zlib.o
popd

# Help the debuginfo generator
ln -s ../../src/modules.c build/base/modules.c
ln -s ../../src/modules.c build/full/modules.c

%files -f %{name}.lang
%{_bindir}/clisp
%{_mandir}/*/*
%{_datadir}/doc
%dir %{_libdir}/%{name}-%{version}
%dir %{_libdir}/%{name}-%{version}/asdf
%{_libdir}/%{name}-%{version}/asdf/asdf.fas
%dir %{_libdir}/%{name}-%{version}/base
%{_libdir}/%{name}-%{version}/base/lispinit.mem
%{_libdir}/%{name}-%{version}/base/lisp.run
%dir %{_libdir}/%{name}-%{version}/bindings
%dir %{_libdir}/%{name}-%{version}/bindings/glibc
%{_libdir}/%{name}-%{version}/bindings/glibc/*.fas
%dir %{_libdir}/%{name}-%{version}/berkeley-db/
%{_libdir}/%{name}-%{version}/berkeley-db/dbi.fas
%dir %{_libdir}/%{name}-%{version}/clx
%dir %{_libdir}/%{name}-%{version}/clx/new-clx
%{_libdir}/%{name}-%{version}/clx/new-clx/*.fas
%{_libdir}/%{name}-%{version}/data
%dir %{_libdir}/%{name}-%{version}/dbus
%{_libdir}/%{name}-%{version}/dbus/*.fas
%dir %{_libdir}/%{name}-%{version}/fastcgi
%{_libdir}/%{name}-%{version}/fastcgi/*.fas
%dir %{_libdir}/%{name}-%{version}/full/
%{_libdir}/%{name}-%{version}/full/lispinit.mem
%{_libdir}/%{name}-%{version}/full/lisp.run
%dir %{_libdir}/%{name}-%{version}/gdbm
%{_libdir}/%{name}-%{version}/gdbm/*.fas
%dir %{_libdir}/%{name}-%{version}/gtk2
%{_libdir}/%{name}-%{version}/gtk2/*.fas
%{_libdir}/%{name}-%{version}/dynmod
%dir %{_libdir}/%{name}-%{version}/pcre
%{_libdir}/%{name}-%{version}/pcre/*.fas
%dir %{_libdir}/%{name}-%{version}/postgresql
%{_libdir}/%{name}-%{version}/postgresql/*.fas
%dir %{_libdir}/%{name}-%{version}/rawsock
%{_libdir}/%{name}-%{version}/rawsock/*.fas
%dir %{_libdir}/%{name}-%{version}/zlib
%{_libdir}/%{name}-%{version}/zlib/*.fas
%{_datadir}/emacs/site-lisp/*
%{_datadir}/vim/vimfiles/after/syntax/lisp.vim

%files devel
%{_bindir}/clisp-link
%{_mandir}/man1/clisp-link.1*
%{_libdir}/%{name}-%{version}/asdf/Makefile
%{_libdir}/%{name}-%{version}/asdf/*.lisp
%{_libdir}/%{name}-%{version}/asdf/*.sh
%{_libdir}/%{name}-%{version}/base/*.a
%{_libdir}/%{name}-%{version}/base/*.h
%{_libdir}/%{name}-%{version}/base/*.o
%{_libdir}/%{name}-%{version}/base/makevars
%{_libdir}/%{name}-%{version}/berkeley-db/Makefile
%{_libdir}/%{name}-%{version}/berkeley-db/*.h
%{_libdir}/%{name}-%{version}/berkeley-db/*.lisp
%{_libdir}/%{name}-%{version}/berkeley-db/*.o
%{_libdir}/%{name}-%{version}/berkeley-db/*.sh
%{_libdir}/%{name}-%{version}/bindings/glibc/Makefile
%{_libdir}/%{name}-%{version}/bindings/glibc/*.lisp
%{_libdir}/%{name}-%{version}/bindings/glibc/*.o
%{_libdir}/%{name}-%{version}/bindings/glibc/*.sh
%{_libdir}/%{name}-%{version}/build-aux/
%{_libdir}/%{name}-%{version}/clx/new-clx/demos/
%{_libdir}/%{name}-%{version}/clx/new-clx/README
%{_libdir}/%{name}-%{version}/clx/new-clx/Makefile
%{_libdir}/%{name}-%{version}/clx/new-clx/*.h
%{_libdir}/%{name}-%{version}/clx/new-clx/*.lisp
%{_libdir}/%{name}-%{version}/clx/new-clx/*.o
%{_libdir}/%{name}-%{version}/clx/new-clx/*.sh
%{_libdir}/%{name}-%{version}/config.h
%{_libdir}/%{name}-%{version}/dbus/Makefile
%{_libdir}/%{name}-%{version}/dbus/*.h
%{_libdir}/%{name}-%{version}/dbus/*.lisp
%{_libdir}/%{name}-%{version}/dbus/*.o
%{_libdir}/%{name}-%{version}/dbus/*.sh
%{_libdir}/%{name}-%{version}/fastcgi/README
%{_libdir}/%{name}-%{version}/fastcgi/Makefile
%{_libdir}/%{name}-%{version}/fastcgi/*.h
%{_libdir}/%{name}-%{version}/fastcgi/*.lisp
%{_libdir}/%{name}-%{version}/fastcgi/*.o
%{_libdir}/%{name}-%{version}/fastcgi/*.sh
%{_libdir}/%{name}-%{version}/full/*.a
%{_libdir}/%{name}-%{version}/full/*.h
%{_libdir}/%{name}-%{version}/full/*.o
%{_libdir}/%{name}-%{version}/full/makevars
%{_libdir}/%{name}-%{version}/gdbm/Makefile
%{_libdir}/%{name}-%{version}/gdbm/*.h
%{_libdir}/%{name}-%{version}/gdbm/*.lisp
%{_libdir}/%{name}-%{version}/gdbm/*.o
%{_libdir}/%{name}-%{version}/gdbm/*.sh
%{_libdir}/%{name}-%{version}/gtk2/Makefile
%{_libdir}/%{name}-%{version}/gtk2/*.cfg
%{_libdir}/%{name}-%{version}/gtk2/*.glade
%{_libdir}/%{name}-%{version}/gtk2/*.h
%{_libdir}/%{name}-%{version}/gtk2/*.lisp
%{_libdir}/%{name}-%{version}/gtk2/*.o
%{_libdir}/%{name}-%{version}/gtk2/*.sh
%if 0
%{_libdir}/%{name}-%{version}/libsvm/README
%{_libdir}/%{name}-%{version}/libsvm/Makefile
%{_libdir}/%{name}-%{version}/libsvm/*.h
%{_libdir}/%{name}-%{version}/libsvm/*.lisp
%{_libdir}/%{name}-%{version}/libsvm/*.o
%{_libdir}/%{name}-%{version}/libsvm/*.sh
%endif
%{_libdir}/%{name}-%{version}/linkkit/
%if 0
%{_libdir}/%{name}-%{version}/pari/README
%{_libdir}/%{name}-%{version}/pari/Makefile
%{_libdir}/%{name}-%{version}/pari/*.h
%{_libdir}/%{name}-%{version}/pari/*.lisp
%{_libdir}/%{name}-%{version}/pari/*.o
%{_libdir}/%{name}-%{version}/pari/*.sh
%endif
%{_libdir}/%{name}-%{version}/pcre/Makefile
%{_libdir}/%{name}-%{version}/pcre/*.h
%{_libdir}/%{name}-%{version}/pcre/*.lisp
%{_libdir}/%{name}-%{version}/pcre/*.o
%{_libdir}/%{name}-%{version}/pcre/*.sh
%{_libdir}/%{name}-%{version}/postgresql/README
%{_libdir}/%{name}-%{version}/postgresql/Makefile
%{_libdir}/%{name}-%{version}/postgresql/*.h
%{_libdir}/%{name}-%{version}/postgresql/*.lisp
%{_libdir}/%{name}-%{version}/postgresql/*.o
%{_libdir}/%{name}-%{version}/postgresql/*.sh
%{_libdir}/%{name}-%{version}/rawsock/demos/
%{_libdir}/%{name}-%{version}/rawsock/Makefile
%{_libdir}/%{name}-%{version}/rawsock/*.h
%{_libdir}/%{name}-%{version}/rawsock/*.lisp
%{_libdir}/%{name}-%{version}/rawsock/*.o
%{_libdir}/%{name}-%{version}/rawsock/*.sh
%{_libdir}/%{name}-%{version}/zlib/Makefile
%{_libdir}/%{name}-%{version}/zlib/*.h
%{_libdir}/%{name}-%{version}/zlib/*.lisp
%{_libdir}/%{name}-%{version}/zlib/*.o
%{_libdir}/%{name}-%{version}/zlib/*.sh
%{_datadir}/aclocal/clisp.m4


%changelog
* Tue Sep 27 2022 tex - 2.49.92-1pclos2022
- new version build against fresh readline
